*** Copyright Notice ***

Justice 40 Tool (J40 Tool) Copyright (c) 2023, The Regents of the University
of California, through Lawrence Berkeley National Laboratory (subject to receipt ofany required approvals from the U.S. 
Dept. of Energy). All rights reserved.

If you have questions about your rights to use or distribute this software,
please contact Berkeley Lab's Intellectual Property Office at
IPO@lbl.gov.

NOTICE.  This Software was developed under funding from the U.S. Department
of Energy and the U.S. Government consequently retains certain rights.  As
such, the U.S. Government has been granted for itself and others acting on
its behalf a paid-up, nonexclusive, irrevocable, worldwide license in the
Software to reproduce, distribute copies to the public, prepare derivative 
works, and perform publicly and display publicly, and to permit others to do so.

***********************************************************************************

# J40 Tool model


## Prerequisites 
You need to run python 3.8 or higher. You can install the required packages with

    pip install -r requirements.txt
    next you should install any pyomo-compatible linear optimization solver
    for example, you can install glpk along with pyomo using conda:
    conda install -c conda-forge glpk
    

## Input Files

- The community files and geo files are published separately




